/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2008-2009 Bull S.A.S.
 * Contact: cmi@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: IConfig.java 2320 2009-05-25 15:00:40Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.controller.common;

import org.ow2.util.component.Components;


/**
 * Define a way to extend dynamically CMI by some stuffs.
 * @author Loris Bouzonnet
 */
public interface IConfig {

    /**
     * Add classes defining interceptors.
     * @param interceptors The interceptors to add.
     */
    void addInterceptors(Class<?>[] interceptors);

    /**
     * @return true if components are auto configured.
     */
    boolean isAutoConfigureComponents();

    /**
     * @return true if Admin is enabled.
     */
    boolean isAdminEnabled();

    /**
     * @return MBean domain name.
     */
    String getMbeanDomainName();

    /**
     * @return MBean name.
     */
    String getMbeanName();

    /**
     * @return Dummy registry's name.
     */
    String getDummyRegistryName();

    /**
     * @return true if the dummy registry is used to lookup the objects that are not clustered.
     */
    boolean isDummyRegistryEnabled();

    /**
     * @return Client provider's name.
     */
    String getClientProviderName();

    /**
     * @return Configuration directory.
     */
    String getConfDir();

    /**
     * @param confDir The configuration directory to set.
     */
    void setConfDir(String confDir);

    /**
     * @return The components.
     */
    Components getComponents();

}
